import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class BigtableAdminResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ProjectsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            def operations(self) -> OperationsResource: ...

        def cancel(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def projects(self) -> ProjectsResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class InstancesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AppProfilesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: AppProfile = ...,
                    appProfileId: str = ...,
                    ignoreWarnings: bool = ...,
                    **kwargs: typing.Any
                ) -> AppProfileHttpRequest: ...
                def delete(
                    self, *, name: str, ignoreWarnings: bool = ..., **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> AppProfileHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListAppProfilesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListAppProfilesResponseHttpRequest,
                    previous_response: ListAppProfilesResponse,
                ) -> ListAppProfilesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: AppProfile = ...,
                    ignoreWarnings: bool = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class ClustersResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class BackupsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: Backup = ...,
                        backupId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> BackupHttpRequest: ...
                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: GetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListBackupsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListBackupsResponseHttpRequest,
                        previous_response: ListBackupsResponse,
                    ) -> ListBackupsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: Backup = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> BackupHttpRequest: ...
                    def setIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: SetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...

                @typing.type_check_only
                class HotTabletsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        endTime: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        startTime: str = ...,
                        **kwargs: typing.Any
                    ) -> ListHotTabletsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListHotTabletsResponseHttpRequest,
                        previous_response: ListHotTabletsResponse,
                    ) -> ListHotTabletsResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: Cluster = ...,
                    clusterId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ClusterHttpRequest: ...
                def list(
                    self, *, parent: str, pageToken: str = ..., **kwargs: typing.Any
                ) -> ListClustersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListClustersResponseHttpRequest,
                    previous_response: ListClustersResponse,
                ) -> ListClustersResponseHttpRequest | None: ...
                def partialUpdateCluster(
                    self,
                    *,
                    name: str,
                    body: Cluster = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def update(
                    self, *, name: str, body: Cluster = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def backups(self) -> BackupsResource: ...
                def hotTablets(self) -> HotTabletsResource: ...

            @typing.type_check_only
            class TablesResource(googleapiclient.discovery.Resource):
                def checkConsistency(
                    self,
                    *,
                    name: str,
                    body: CheckConsistencyRequest = ...,
                    **kwargs: typing.Any
                ) -> CheckConsistencyResponseHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: CreateTableRequest = ...,
                    **kwargs: typing.Any
                ) -> TableHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def dropRowRange(
                    self,
                    *,
                    name: str,
                    body: DropRowRangeRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def generateConsistencyToken(
                    self,
                    *,
                    name: str,
                    body: GenerateConsistencyTokenRequest = ...,
                    **kwargs: typing.Any
                ) -> GenerateConsistencyTokenResponseHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    view: typing_extensions.Literal[
                        "VIEW_UNSPECIFIED",
                        "NAME_ONLY",
                        "SCHEMA_VIEW",
                        "REPLICATION_VIEW",
                        "ENCRYPTION_VIEW",
                        "FULL",
                    ] = ...,
                    **kwargs: typing.Any
                ) -> TableHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: GetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    view: typing_extensions.Literal[
                        "VIEW_UNSPECIFIED",
                        "NAME_ONLY",
                        "SCHEMA_VIEW",
                        "REPLICATION_VIEW",
                        "ENCRYPTION_VIEW",
                        "FULL",
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ListTablesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTablesResponseHttpRequest,
                    previous_response: ListTablesResponse,
                ) -> ListTablesResponseHttpRequest | None: ...
                def modifyColumnFamilies(
                    self,
                    *,
                    name: str,
                    body: ModifyColumnFamiliesRequest = ...,
                    **kwargs: typing.Any
                ) -> TableHttpRequest: ...
                def restore(
                    self,
                    *,
                    parent: str,
                    body: RestoreTableRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def undelete(
                    self,
                    *,
                    name: str,
                    body: UndeleteTableRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            def create(
                self,
                *,
                parent: str,
                body: CreateInstanceRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> InstanceHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                body: GetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self, *, parent: str, pageToken: str = ..., **kwargs: typing.Any
            ) -> ListInstancesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListInstancesResponseHttpRequest,
                previous_response: ListInstancesResponse,
            ) -> ListInstancesResponseHttpRequest | None: ...
            def partialUpdateInstance(
                self,
                *,
                name: str,
                body: Instance = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...
            def update(
                self, *, name: str, body: Instance = ..., **kwargs: typing.Any
            ) -> InstanceHttpRequest: ...
            def appProfiles(self) -> AppProfilesResource: ...
            def clusters(self) -> ClustersResource: ...
            def tables(self) -> TablesResource: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...

        def instances(self) -> InstancesResource: ...
        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def operations(self) -> OperationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class AppProfileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AppProfile: ...

@typing.type_check_only
class BackupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Backup: ...

@typing.type_check_only
class CheckConsistencyResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CheckConsistencyResponse: ...

@typing.type_check_only
class ClusterHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Cluster: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GenerateConsistencyTokenResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GenerateConsistencyTokenResponse: ...

@typing.type_check_only
class InstanceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Instance: ...

@typing.type_check_only
class ListAppProfilesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAppProfilesResponse: ...

@typing.type_check_only
class ListBackupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBackupsResponse: ...

@typing.type_check_only
class ListClustersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClustersResponse: ...

@typing.type_check_only
class ListHotTabletsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListHotTabletsResponse: ...

@typing.type_check_only
class ListInstancesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListInstancesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListTablesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTablesResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class TableHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Table: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DoubleClickBidManagerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class QueriesResource(googleapiclient.discovery.Resource):
        def createquery(
            self, *, body: Query = ..., asynchronous: bool = ..., **kwargs: typing.Any
        ) -> QueryHttpRequest: ...
        def deletequery(
            self, *, queryId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def getquery(
            self, *, queryId: str, **kwargs: typing.Any
        ) -> QueryHttpRequest: ...
        def listqueries(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> ListQueriesResponseHttpRequest: ...
        def listqueries_next(
            self,
            previous_request: ListQueriesResponseHttpRequest,
            previous_response: ListQueriesResponse,
        ) -> ListQueriesResponseHttpRequest | None: ...
        def runquery(
            self,
            *,
            queryId: str,
            body: RunQueryRequest = ...,
            asynchronous: bool = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class ReportsResource(googleapiclient.discovery.Resource):
        def listreports(
            self,
            *,
            queryId: str,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListReportsResponseHttpRequest: ...
        def listreports_next(
            self,
            previous_request: ListReportsResponseHttpRequest,
            previous_response: ListReportsResponse,
        ) -> ListReportsResponseHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def queries(self) -> QueriesResource: ...
    def reports(self) -> ReportsResource: ...

@typing.type_check_only
class ListQueriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListQueriesResponse: ...

@typing.type_check_only
class ListReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReportsResponse: ...

@typing.type_check_only
class QueryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Query: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ContainerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AggregatedResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class UsableSubnetworksResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListUsableSubnetworksResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListUsableSubnetworksResponseHttpRequest,
                    previous_response: ListUsableSubnetworksResponse,
                ) -> ListUsableSubnetworksResponseHttpRequest | None: ...

            def usableSubnetworks(self) -> UsableSubnetworksResource: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ClustersResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class NodePoolsResource(googleapiclient.discovery.Resource):
                    def completeUpgrade(
                        self,
                        *,
                        name: str,
                        body: CompleteNodePoolUpgradeRequest = ...,
                        **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def create(
                        self,
                        *,
                        parent: str,
                        body: CreateNodePoolRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self,
                        *,
                        name: str,
                        clusterId: str = ...,
                        nodePoolId: str = ...,
                        projectId: str = ...,
                        zone: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self,
                        *,
                        name: str,
                        clusterId: str = ...,
                        nodePoolId: str = ...,
                        projectId: str = ...,
                        zone: str = ...,
                        **kwargs: typing.Any
                    ) -> NodePoolHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        clusterId: str = ...,
                        projectId: str = ...,
                        zone: str = ...,
                        **kwargs: typing.Any
                    ) -> ListNodePoolsResponseHttpRequest: ...
                    def rollback(
                        self,
                        *,
                        name: str,
                        body: RollbackNodePoolUpgradeRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def setAutoscaling(
                        self,
                        *,
                        name: str,
                        body: SetNodePoolAutoscalingRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def setManagement(
                        self,
                        *,
                        name: str,
                        body: SetNodePoolManagementRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def setSize(
                        self,
                        *,
                        name: str,
                        body: SetNodePoolSizeRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def update(
                        self,
                        *,
                        name: str,
                        body: UpdateNodePoolRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                @typing.type_check_only
                class WellKnownResource(googleapiclient.discovery.Resource):
                    def getOpenid_configuration(
                        self, *, parent: str, **kwargs: typing.Any
                    ) -> GetOpenIDConfigResponseHttpRequest: ...

                def completeIpRotation(
                    self,
                    *,
                    name: str,
                    body: CompleteIPRotationRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: CreateClusterRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    clusterId: str = ...,
                    projectId: str = ...,
                    zone: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    clusterId: str = ...,
                    projectId: str = ...,
                    zone: str = ...,
                    **kwargs: typing.Any
                ) -> ClusterHttpRequest: ...
                def getJwks(
                    self, *, parent: str, **kwargs: typing.Any
                ) -> GetJSONWebKeysResponseHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    projectId: str = ...,
                    zone: str = ...,
                    **kwargs: typing.Any
                ) -> ListClustersResponseHttpRequest: ...
                def setAddons(
                    self,
                    *,
                    name: str,
                    body: SetAddonsConfigRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setLegacyAbac(
                    self,
                    *,
                    name: str,
                    body: SetLegacyAbacRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setLocations(
                    self,
                    *,
                    name: str,
                    body: SetLocationsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setLogging(
                    self,
                    *,
                    name: str,
                    body: SetLoggingServiceRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setMaintenancePolicy(
                    self,
                    *,
                    name: str,
                    body: SetMaintenancePolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setMasterAuth(
                    self,
                    *,
                    name: str,
                    body: SetMasterAuthRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setMonitoring(
                    self,
                    *,
                    name: str,
                    body: SetMonitoringServiceRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setNetworkPolicy(
                    self,
                    *,
                    name: str,
                    body: SetNetworkPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setResourceLabels(
                    self,
                    *,
                    name: str,
                    body: SetLabelsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def startIpRotation(
                    self,
                    *,
                    name: str,
                    body: StartIPRotationRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def update(
                    self,
                    *,
                    name: str,
                    body: UpdateClusterRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def updateMaster(
                    self,
                    *,
                    name: str,
                    body: UpdateMasterRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def nodePools(self) -> NodePoolsResource: ...
                def well_known(self) -> WellKnownResource: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    operationId: str = ...,
                    projectId: str = ...,
                    zone: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    projectId: str = ...,
                    zone: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...

            def getServerConfig(
                self,
                *,
                name: str,
                projectId: str = ...,
                zone: str = ...,
                **kwargs: typing.Any
            ) -> ServerConfigHttpRequest: ...
            def list(
                self, *, parent: str, **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def clusters(self) -> ClustersResource: ...
            def operations(self) -> OperationsResource: ...

        @typing.type_check_only
        class ZonesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ClustersResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class NodePoolsResource(googleapiclient.discovery.Resource):
                    def autoscaling(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        nodePoolId: str,
                        body: SetNodePoolAutoscalingRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def create(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        body: CreateNodePoolRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        nodePoolId: str,
                        name: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        nodePoolId: str,
                        name: str = ...,
                        **kwargs: typing.Any
                    ) -> NodePoolHttpRequest: ...
                    def list(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        parent: str = ...,
                        **kwargs: typing.Any
                    ) -> ListNodePoolsResponseHttpRequest: ...
                    def rollback(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        nodePoolId: str,
                        body: RollbackNodePoolUpgradeRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def setManagement(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        nodePoolId: str,
                        body: SetNodePoolManagementRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def setSize(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        nodePoolId: str,
                        body: SetNodePoolSizeRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def update(
                        self,
                        *,
                        projectId: str,
                        zone: str,
                        clusterId: str,
                        nodePoolId: str,
                        body: UpdateNodePoolRequest = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                def addons(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetAddonsConfigRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def completeIpRotation(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: CompleteIPRotationRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def create(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    body: CreateClusterRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    name: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    name: str = ...,
                    **kwargs: typing.Any
                ) -> ClusterHttpRequest: ...
                def legacyAbac(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetLegacyAbacRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    parent: str = ...,
                    **kwargs: typing.Any
                ) -> ListClustersResponseHttpRequest: ...
                def locations(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetLocationsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def logging(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetLoggingServiceRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def master(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: UpdateMasterRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def monitoring(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetMonitoringServiceRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def resourceLabels(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetLabelsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setMaintenancePolicy(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetMaintenancePolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setMasterAuth(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetMasterAuthRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setNetworkPolicy(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: SetNetworkPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def startIpRotation(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: StartIPRotationRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def update(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    clusterId: str,
                    body: UpdateClusterRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def nodePools(self) -> NodePoolsResource: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    operationId: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    operationId: str,
                    name: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    projectId: str,
                    zone: str,
                    parent: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...

            def getServerconfig(
                self,
                *,
                projectId: str,
                zone: str,
                name: str = ...,
                **kwargs: typing.Any
            ) -> ServerConfigHttpRequest: ...
            def clusters(self) -> ClustersResource: ...
            def operations(self) -> OperationsResource: ...

        def aggregated(self) -> AggregatedResource: ...
        def locations(self) -> LocationsResource: ...
        def zones(self) -> ZonesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class ClusterHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Cluster: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GetJSONWebKeysResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetJSONWebKeysResponse: ...

@typing.type_check_only
class GetOpenIDConfigResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetOpenIDConfigResponse: ...

@typing.type_check_only
class ListClustersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClustersResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListNodePoolsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListNodePoolsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListUsableSubnetworksResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListUsableSubnetworksResponse: ...

@typing.type_check_only
class NodePoolHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> NodePool: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ServerConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServerConfig: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleApiHttpBody(typing_extensions.TypedDict, total=False):
    contentType: str
    data: str
    extensions: _list[dict[str, typing.Any]]

@typing.type_check_only
class GoogleCloudRecommendationengineV1alphaRejoinCatalogMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1alphaRejoinCatalogResponse(
    typing_extensions.TypedDict, total=False
):
    rejoinedUserEventsCount: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1alphaTuningMetadata(
    typing_extensions.TypedDict, total=False
):
    recommendationModel: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1alphaTuningResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1BigQuerySource(
    typing_extensions.TypedDict, total=False
):
    dataSchema: str
    datasetId: str
    gcsStagingDir: str
    projectId: str
    tableId: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1Catalog(
    typing_extensions.TypedDict, total=False
):
    catalogItemLevelConfig: GoogleCloudRecommendationengineV1beta1CatalogItemLevelConfig
    defaultEventStoreId: str
    displayName: str
    name: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1CatalogInlineSource(
    typing_extensions.TypedDict, total=False
):
    catalogItems: _list[GoogleCloudRecommendationengineV1beta1CatalogItem]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1CatalogItem(
    typing_extensions.TypedDict, total=False
):
    categoryHierarchies: _list[
        GoogleCloudRecommendationengineV1beta1CatalogItemCategoryHierarchy
    ]
    description: str
    id: str
    itemAttributes: GoogleCloudRecommendationengineV1beta1FeatureMap
    itemGroupId: str
    languageCode: str
    productMetadata: GoogleCloudRecommendationengineV1beta1ProductCatalogItem
    tags: _list[str]
    title: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1CatalogItemCategoryHierarchy(
    typing_extensions.TypedDict, total=False
):
    categories: _list[str]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1CatalogItemLevelConfig(
    typing_extensions.TypedDict, total=False
):
    eventItemLevel: typing_extensions.Literal[
        "CATALOG_ITEM_LEVEL_UNSPECIFIED", "VARIANT", "MASTER"
    ]
    predictItemLevel: typing_extensions.Literal[
        "CATALOG_ITEM_LEVEL_UNSPECIFIED", "VARIANT", "MASTER"
    ]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1CreatePredictionApiKeyRegistrationRequest(
    typing_extensions.TypedDict, total=False
):
    predictionApiKeyRegistration: GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistration

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1EventDetail(
    typing_extensions.TypedDict, total=False
):
    eventAttributes: GoogleCloudRecommendationengineV1beta1FeatureMap
    experimentIds: _list[str]
    pageViewId: str
    recommendationToken: str
    referrerUri: str
    uri: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1FeatureMap(
    typing_extensions.TypedDict, total=False
):
    categoricalFeatures: dict[str, typing.Any]
    numericalFeatures: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1FeatureMapFloatList(
    typing_extensions.TypedDict, total=False
):
    value: _list[float]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1FeatureMapStringList(
    typing_extensions.TypedDict, total=False
):
    value: _list[str]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1GcsSource(
    typing_extensions.TypedDict, total=False
):
    inputUris: _list[str]
    jsonSchema: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1Image(
    typing_extensions.TypedDict, total=False
):
    height: int
    uri: str
    width: int

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ImportCatalogItemsRequest(
    typing_extensions.TypedDict, total=False
):
    errorsConfig: GoogleCloudRecommendationengineV1beta1ImportErrorsConfig
    inputConfig: GoogleCloudRecommendationengineV1beta1InputConfig
    requestId: str
    updateMask: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ImportCatalogItemsResponse(
    typing_extensions.TypedDict, total=False
):
    errorSamples: _list[GoogleRpcStatus]
    errorsConfig: GoogleCloudRecommendationengineV1beta1ImportErrorsConfig

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ImportErrorsConfig(
    typing_extensions.TypedDict, total=False
):
    gcsPrefix: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ImportMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    failureCount: str
    operationName: str
    requestId: str
    successCount: str
    updateTime: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ImportUserEventsRequest(
    typing_extensions.TypedDict, total=False
):
    errorsConfig: GoogleCloudRecommendationengineV1beta1ImportErrorsConfig
    inputConfig: GoogleCloudRecommendationengineV1beta1InputConfig
    requestId: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ImportUserEventsResponse(
    typing_extensions.TypedDict, total=False
):
    errorSamples: _list[GoogleRpcStatus]
    errorsConfig: GoogleCloudRecommendationengineV1beta1ImportErrorsConfig
    importSummary: GoogleCloudRecommendationengineV1beta1UserEventImportSummary

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1InputConfig(
    typing_extensions.TypedDict, total=False
):
    bigQuerySource: GoogleCloudRecommendationengineV1beta1BigQuerySource
    catalogInlineSource: GoogleCloudRecommendationengineV1beta1CatalogInlineSource
    gcsSource: GoogleCloudRecommendationengineV1beta1GcsSource
    userEventInlineSource: GoogleCloudRecommendationengineV1beta1UserEventInlineSource

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListCatalogItemsResponse(
    typing_extensions.TypedDict, total=False
):
    catalogItems: _list[GoogleCloudRecommendationengineV1beta1CatalogItem]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListCatalogsResponse(
    typing_extensions.TypedDict, total=False
):
    catalogs: _list[GoogleCloudRecommendationengineV1beta1Catalog]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListPredictionApiKeyRegistrationsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    predictionApiKeyRegistrations: _list[
        GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistration
    ]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ListUserEventsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    userEvents: _list[GoogleCloudRecommendationengineV1beta1UserEvent]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PredictRequest(
    typing_extensions.TypedDict, total=False
):
    dryRun: bool
    filter: str
    labels: dict[str, typing.Any]
    pageSize: int
    pageToken: str
    params: dict[str, typing.Any]
    userEvent: GoogleCloudRecommendationengineV1beta1UserEvent

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PredictResponse(
    typing_extensions.TypedDict, total=False
):
    dryRun: bool
    itemsMissingInCatalog: _list[str]
    metadata: dict[str, typing.Any]
    nextPageToken: str
    recommendationToken: str
    results: _list[
        GoogleCloudRecommendationengineV1beta1PredictResponsePredictionResult
    ]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PredictResponsePredictionResult(
    typing_extensions.TypedDict, total=False
):
    id: str
    itemMetadata: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PredictionApiKeyRegistration(
    typing_extensions.TypedDict, total=False
):
    apiKey: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ProductCatalogItem(
    typing_extensions.TypedDict, total=False
):
    availableQuantity: str
    canonicalProductUri: str
    costs: dict[str, typing.Any]
    currencyCode: str
    exactPrice: GoogleCloudRecommendationengineV1beta1ProductCatalogItemExactPrice
    images: _list[GoogleCloudRecommendationengineV1beta1Image]
    priceRange: GoogleCloudRecommendationengineV1beta1ProductCatalogItemPriceRange
    stockState: typing_extensions.Literal[
        "STOCK_STATE_UNSPECIFIED", "IN_STOCK", "OUT_OF_STOCK", "PREORDER", "BACKORDER"
    ]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ProductCatalogItemExactPrice(
    typing_extensions.TypedDict, total=False
):
    displayPrice: float
    originalPrice: float

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ProductCatalogItemPriceRange(
    typing_extensions.TypedDict, total=False
):
    max: float
    min: float

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ProductDetail(
    typing_extensions.TypedDict, total=False
):
    availableQuantity: int
    currencyCode: str
    displayPrice: float
    id: str
    itemAttributes: GoogleCloudRecommendationengineV1beta1FeatureMap
    originalPrice: float
    quantity: int
    stockState: typing_extensions.Literal[
        "STOCK_STATE_UNSPECIFIED", "IN_STOCK", "OUT_OF_STOCK", "PREORDER", "BACKORDER"
    ]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1ProductEventDetail(
    typing_extensions.TypedDict, total=False
):
    cartId: str
    listId: str
    pageCategories: _list[
        GoogleCloudRecommendationengineV1beta1CatalogItemCategoryHierarchy
    ]
    productDetails: _list[GoogleCloudRecommendationengineV1beta1ProductDetail]
    purchaseTransaction: GoogleCloudRecommendationengineV1beta1PurchaseTransaction
    searchQuery: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PurchaseTransaction(
    typing_extensions.TypedDict, total=False
):
    costs: dict[str, typing.Any]
    currencyCode: str
    id: str
    revenue: float
    taxes: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PurgeUserEventsMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    operationName: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PurgeUserEventsRequest(
    typing_extensions.TypedDict, total=False
):
    filter: str
    force: bool

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1PurgeUserEventsResponse(
    typing_extensions.TypedDict, total=False
):
    purgedEventsCount: str
    userEventsSample: _list[GoogleCloudRecommendationengineV1beta1UserEvent]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1RejoinUserEventsMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1RejoinUserEventsRequest(
    typing_extensions.TypedDict, total=False
):
    userEventRejoinScope: typing_extensions.Literal[
        "USER_EVENT_REJOIN_SCOPE_UNSPECIFIED", "JOINED_EVENTS", "UNJOINED_EVENTS"
    ]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1RejoinUserEventsResponse(
    typing_extensions.TypedDict, total=False
):
    rejoinedUserEventsCount: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1UserEvent(
    typing_extensions.TypedDict, total=False
):
    eventDetail: GoogleCloudRecommendationengineV1beta1EventDetail
    eventSource: typing_extensions.Literal[
        "EVENT_SOURCE_UNSPECIFIED", "AUTOML", "ECOMMERCE", "BATCH_UPLOAD"
    ]
    eventTime: str
    eventType: str
    productEventDetail: GoogleCloudRecommendationengineV1beta1ProductEventDetail
    userInfo: GoogleCloudRecommendationengineV1beta1UserInfo

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1UserEventImportSummary(
    typing_extensions.TypedDict, total=False
):
    joinedEventsCount: str
    unjoinedEventsCount: str

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1UserEventInlineSource(
    typing_extensions.TypedDict, total=False
):
    userEvents: _list[GoogleCloudRecommendationengineV1beta1UserEvent]

@typing.type_check_only
class GoogleCloudRecommendationengineV1beta1UserInfo(
    typing_extensions.TypedDict, total=False
):
    directUserRequest: bool
    ipAddress: str
    userAgent: str
    userId: str
    visitorId: str

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Task(typing_extensions.TypedDict, total=False):
    completed: str
    deleted: bool
    due: str
    etag: str
    hidden: bool
    id: str
    kind: str
    links: _list[dict[str, typing.Any]]
    notes: str
    parent: str
    position: str
    selfLink: str
    status: str
    title: str
    updated: str

@typing.type_check_only
class TaskList(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    selfLink: str
    title: str
    updated: str

@typing.type_check_only
class TaskLists(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[TaskList]
    kind: str
    nextPageToken: str

@typing.type_check_only
class Tasks(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[Task]
    kind: str
    nextPageToken: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class KeepResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class MediaResource(googleapiclient.discovery.Resource):
        def download(
            self, *, name: str, mimeType: str = ..., **kwargs: typing.Any
        ) -> AttachmentHttpRequest: ...
        def download_media(
            self, *, name: str, mimeType: str = ..., **kwargs: typing.Any
        ) -> BytesHttpRequest: ...

    @typing.type_check_only
    class NotesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class PermissionsResource(googleapiclient.discovery.Resource):
            def batchCreate(
                self,
                *,
                parent: str,
                body: BatchCreatePermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> BatchCreatePermissionsResponseHttpRequest: ...
            def batchDelete(
                self,
                *,
                parent: str,
                body: BatchDeletePermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...

        def create(
            self, *, body: Note = ..., **kwargs: typing.Any
        ) -> NoteHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> NoteHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListNotesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListNotesResponseHttpRequest,
            previous_response: ListNotesResponse,
        ) -> ListNotesResponseHttpRequest | None: ...
        def permissions(self) -> PermissionsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def media(self) -> MediaResource: ...
    def notes(self) -> NotesResource: ...

@typing.type_check_only
class AttachmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Attachment: ...

@typing.type_check_only
class BatchCreatePermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchCreatePermissionsResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListNotesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListNotesResponse: ...

@typing.type_check_only
class NoteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Note: ...

@typing.type_check_only
class BytesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> bytes: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FirebaseDynamicLinksResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ManagedShortLinksResource(googleapiclient.discovery.Resource):
        def create(
            self, *, body: CreateManagedShortLinkRequest = ..., **kwargs: typing.Any
        ) -> CreateManagedShortLinkResponseHttpRequest: ...

    @typing.type_check_only
    class ShortLinksResource(googleapiclient.discovery.Resource):
        def create(
            self, *, body: CreateShortDynamicLinkRequest = ..., **kwargs: typing.Any
        ) -> CreateShortDynamicLinkResponseHttpRequest: ...

    @typing.type_check_only
    class V1Resource(googleapiclient.discovery.Resource):
        def getLinkStats(
            self,
            *,
            dynamicLink: str,
            durationDays: str = ...,
            sdkVersion: str = ...,
            **kwargs: typing.Any
        ) -> DynamicLinkStatsHttpRequest: ...
        def installAttribution(
            self,
            *,
            body: GetIosPostInstallAttributionRequest = ...,
            **kwargs: typing.Any
        ) -> GetIosPostInstallAttributionResponseHttpRequest: ...
        def reopenAttribution(
            self, *, body: GetIosReopenAttributionRequest = ..., **kwargs: typing.Any
        ) -> GetIosReopenAttributionResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def managedShortLinks(self) -> ManagedShortLinksResource: ...
    def shortLinks(self) -> ShortLinksResource: ...
    def v1(self) -> V1Resource: ...

@typing.type_check_only
class CreateManagedShortLinkResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CreateManagedShortLinkResponse: ...

@typing.type_check_only
class CreateShortDynamicLinkResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CreateShortDynamicLinkResponse: ...

@typing.type_check_only
class DynamicLinkStatsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DynamicLinkStats: ...

@typing.type_check_only
class GetIosPostInstallAttributionResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetIosPostInstallAttributionResponse: ...

@typing.type_check_only
class GetIosReopenAttributionResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetIosReopenAttributionResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AcceleratorConfig(typing_extensions.TypedDict, total=False):
    acceleratorCount: str
    acceleratorType: str
    gpuPartitionSize: str
    gpuSharingConfig: GPUSharingConfig
    maxTimeSharedClientsPerGpu: str

@typing.type_check_only
class AddonsConfig(typing_extensions.TypedDict, total=False):
    cloudRunConfig: CloudRunConfig
    configConnectorConfig: ConfigConnectorConfig
    dnsCacheConfig: DnsCacheConfig
    gcePersistentDiskCsiDriverConfig: GcePersistentDiskCsiDriverConfig
    gcpFilestoreCsiDriverConfig: GcpFilestoreCsiDriverConfig
    gkeBackupAgentConfig: GkeBackupAgentConfig
    horizontalPodAutoscaling: HorizontalPodAutoscaling
    httpLoadBalancing: HttpLoadBalancing
    istioConfig: IstioConfig
    kalmConfig: KalmConfig
    kubernetesDashboard: KubernetesDashboard
    networkPolicyConfig: NetworkPolicyConfig

@typing.type_check_only
class AdvancedMachineFeatures(typing_extensions.TypedDict, total=False):
    threadsPerCore: str

@typing.type_check_only
class AuthenticatorGroupsConfig(typing_extensions.TypedDict, total=False):
    enabled: bool
    securityGroup: str

@typing.type_check_only
class AutoUpgradeOptions(typing_extensions.TypedDict, total=False):
    autoUpgradeStartTime: str
    description: str

@typing.type_check_only
class Autopilot(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class AutoprovisioningNodePoolDefaults(typing_extensions.TypedDict, total=False):
    bootDiskKmsKey: str
    diskSizeGb: int
    diskType: str
    imageType: str
    management: NodeManagement
    minCpuPlatform: str
    oauthScopes: _list[str]
    serviceAccount: str
    shieldedInstanceConfig: ShieldedInstanceConfig
    upgradeSettings: UpgradeSettings

@typing.type_check_only
class AvailableVersion(typing_extensions.TypedDict, total=False):
    reason: str
    version: str

@typing.type_check_only
class BigQueryDestination(typing_extensions.TypedDict, total=False):
    datasetId: str

@typing.type_check_only
class BinaryAuthorization(typing_extensions.TypedDict, total=False):
    enabled: bool
    evaluationMode: typing_extensions.Literal[
        "EVALUATION_MODE_UNSPECIFIED", "DISABLED", "PROJECT_SINGLETON_POLICY_ENFORCE"
    ]

@typing.type_check_only
class BlueGreenInfo(typing_extensions.TypedDict, total=False):
    blueInstanceGroupUrls: _list[str]
    bluePoolDeletionStartTime: str
    greenInstanceGroupUrls: _list[str]
    greenPoolVersion: str
    phase: typing_extensions.Literal[
        "PHASE_UNSPECIFIED",
        "UPDATE_STARTED",
        "CREATING_GREEN_POOL",
        "CORDONING_BLUE_POOL",
        "DRAINING_BLUE_POOL",
        "NODE_POOL_SOAKING",
        "DELETING_BLUE_POOL",
        "ROLLBACK_STARTED",
    ]

@typing.type_check_only
class BlueGreenSettings(typing_extensions.TypedDict, total=False):
    nodePoolSoakDuration: str
    standardRolloutPolicy: StandardRolloutPolicy

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False):
    name: str
    operationId: str
    projectId: str
    zone: str

@typing.type_check_only
class CidrBlock(typing_extensions.TypedDict, total=False):
    cidrBlock: str
    displayName: str

@typing.type_check_only
class ClientCertificateConfig(typing_extensions.TypedDict, total=False):
    issueClientCertificate: bool

@typing.type_check_only
class CloudRunConfig(typing_extensions.TypedDict, total=False):
    disabled: bool
    loadBalancerType: typing_extensions.Literal[
        "LOAD_BALANCER_TYPE_UNSPECIFIED",
        "LOAD_BALANCER_TYPE_EXTERNAL",
        "LOAD_BALANCER_TYPE_INTERNAL",
    ]

@typing.type_check_only
class Cluster(typing_extensions.TypedDict, total=False):
    addonsConfig: AddonsConfig
    authenticatorGroupsConfig: AuthenticatorGroupsConfig
    autopilot: Autopilot
    autoscaling: ClusterAutoscaling
    binaryAuthorization: BinaryAuthorization
    clusterIpv4Cidr: str
    clusterTelemetry: ClusterTelemetry
    conditions: _list[StatusCondition]
    confidentialNodes: ConfidentialNodes
    costManagementConfig: CostManagementConfig
    createTime: str
    currentMasterVersion: str
    currentNodeCount: int
    currentNodeVersion: str
    databaseEncryption: DatabaseEncryption
    defaultMaxPodsConstraint: MaxPodsConstraint
    description: str
    enableKubernetesAlpha: bool
    enableTpu: bool
    endpoint: str
    expireTime: str
    id: str
    identityServiceConfig: IdentityServiceConfig
    initialClusterVersion: str
    initialNodeCount: int
    instanceGroupUrls: _list[str]
    ipAllocationPolicy: IPAllocationPolicy
    labelFingerprint: str
    legacyAbac: LegacyAbac
    location: str
    locations: _list[str]
    loggingConfig: LoggingConfig
    loggingService: str
    maintenancePolicy: MaintenancePolicy
    master: Master
    masterAuth: MasterAuth
    masterAuthorizedNetworksConfig: MasterAuthorizedNetworksConfig
    masterIpv4CidrBlock: str
    meshCertificates: MeshCertificates
    monitoringConfig: MonitoringConfig
    monitoringService: str
    name: str
    network: str
    networkConfig: NetworkConfig
    networkPolicy: NetworkPolicy
    nodeConfig: NodeConfig
    nodeIpv4CidrSize: int
    nodePoolAutoConfig: NodePoolAutoConfig
    nodePoolDefaults: NodePoolDefaults
    nodePools: _list[NodePool]
    notificationConfig: NotificationConfig
    podSecurityPolicyConfig: PodSecurityPolicyConfig
    privateCluster: bool
    privateClusterConfig: PrivateClusterConfig
    protectConfig: ProtectConfig
    releaseChannel: ReleaseChannel
    resourceLabels: dict[str, typing.Any]
    resourceUsageExportConfig: ResourceUsageExportConfig
    selfLink: str
    servicesIpv4Cidr: str
    shieldedNodes: ShieldedNodes
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "PROVISIONING",
        "RUNNING",
        "RECONCILING",
        "STOPPING",
        "ERROR",
        "DEGRADED",
    ]
    statusMessage: str
    subnetwork: str
    tpuConfig: TpuConfig
    tpuIpv4CidrBlock: str
    verticalPodAutoscaling: VerticalPodAutoscaling
    workloadAltsConfig: WorkloadALTSConfig
    workloadCertificates: WorkloadCertificates
    workloadIdentityConfig: WorkloadIdentityConfig
    zone: str

@typing.type_check_only
class ClusterAutoscaling(typing_extensions.TypedDict, total=False):
    autoprovisioningLocations: _list[str]
    autoprovisioningNodePoolDefaults: AutoprovisioningNodePoolDefaults
    autoscalingProfile: typing_extensions.Literal[
        "PROFILE_UNSPECIFIED", "OPTIMIZE_UTILIZATION", "BALANCED"
    ]
    enableNodeAutoprovisioning: bool
    resourceLimits: _list[ResourceLimit]

@typing.type_check_only
class ClusterTelemetry(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["UNSPECIFIED", "DISABLED", "ENABLED", "SYSTEM_ONLY"]

@typing.type_check_only
class ClusterUpdate(typing_extensions.TypedDict, total=False):
    desiredAddonsConfig: AddonsConfig
    desiredAuthenticatorGroupsConfig: AuthenticatorGroupsConfig
    desiredBinaryAuthorization: BinaryAuthorization
    desiredClusterAutoscaling: ClusterAutoscaling
    desiredClusterTelemetry: ClusterTelemetry
    desiredCostManagementConfig: CostManagementConfig
    desiredDatabaseEncryption: DatabaseEncryption
    desiredDatapathProvider: typing_extensions.Literal[
        "DATAPATH_PROVIDER_UNSPECIFIED", "LEGACY_DATAPATH", "ADVANCED_DATAPATH"
    ]
    desiredDefaultSnatStatus: DefaultSnatStatus
    desiredDnsConfig: DNSConfig
    desiredGcfsConfig: GcfsConfig
    desiredIdentityServiceConfig: IdentityServiceConfig
    desiredImageType: str
    desiredIntraNodeVisibilityConfig: IntraNodeVisibilityConfig
    desiredL4ilbSubsettingConfig: ILBSubsettingConfig
    desiredLocations: _list[str]
    desiredLoggingConfig: LoggingConfig
    desiredLoggingService: str
    desiredMaster: Master
    desiredMasterAuthorizedNetworksConfig: MasterAuthorizedNetworksConfig
    desiredMasterVersion: str
    desiredMeshCertificates: MeshCertificates
    desiredMonitoringConfig: MonitoringConfig
    desiredMonitoringService: str
    desiredNodePoolAutoConfigNetworkTags: NetworkTags
    desiredNodePoolAutoscaling: NodePoolAutoscaling
    desiredNodePoolId: str
    desiredNodePoolLoggingConfig: NodePoolLoggingConfig
    desiredNodeVersion: str
    desiredNotificationConfig: NotificationConfig
    desiredPodSecurityPolicyConfig: PodSecurityPolicyConfig
    desiredPrivateClusterConfig: PrivateClusterConfig
    desiredPrivateIpv6GoogleAccess: typing_extensions.Literal[
        "PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED",
        "PRIVATE_IPV6_GOOGLE_ACCESS_DISABLED",
        "PRIVATE_IPV6_GOOGLE_ACCESS_TO_GOOGLE",
        "PRIVATE_IPV6_GOOGLE_ACCESS_BIDIRECTIONAL",
    ]
    desiredProtectConfig: ProtectConfig
    desiredReleaseChannel: ReleaseChannel
    desiredResourceUsageExportConfig: ResourceUsageExportConfig
    desiredServiceExternalIpsConfig: ServiceExternalIPsConfig
    desiredShieldedNodes: ShieldedNodes
    desiredTpuConfig: TpuConfig
    desiredVerticalPodAutoscaling: VerticalPodAutoscaling
    desiredWorkloadAltsConfig: WorkloadALTSConfig
    desiredWorkloadCertificates: WorkloadCertificates
    desiredWorkloadIdentityConfig: WorkloadIdentityConfig

@typing.type_check_only
class CompleteIPRotationRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class CompleteNodePoolUpgradeRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ConfidentialNodes(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class ConfigConnectorConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class ConsumptionMeteringConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class CostManagementConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class CreateClusterRequest(typing_extensions.TypedDict, total=False):
    cluster: Cluster
    parent: str
    projectId: str
    zone: str

@typing.type_check_only
class CreateNodePoolRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    nodePool: NodePool
    parent: str
    projectId: str
    zone: str

@typing.type_check_only
class DNSConfig(typing_extensions.TypedDict, total=False):
    clusterDns: typing_extensions.Literal[
        "PROVIDER_UNSPECIFIED", "PLATFORM_DEFAULT", "CLOUD_DNS"
    ]
    clusterDnsDomain: str
    clusterDnsScope: typing_extensions.Literal[
        "DNS_SCOPE_UNSPECIFIED", "CLUSTER_SCOPE", "VPC_SCOPE"
    ]

@typing.type_check_only
class DailyMaintenanceWindow(typing_extensions.TypedDict, total=False):
    duration: str
    startTime: str

@typing.type_check_only
class DatabaseEncryption(typing_extensions.TypedDict, total=False):
    keyName: str
    state: typing_extensions.Literal["UNKNOWN", "ENCRYPTED", "DECRYPTED"]

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class DefaultSnatStatus(typing_extensions.TypedDict, total=False):
    disabled: bool

@typing.type_check_only
class DnsCacheConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EphemeralStorageConfig(typing_extensions.TypedDict, total=False):
    localSsdCount: int

@typing.type_check_only
class Filter(typing_extensions.TypedDict, total=False):
    eventType: _list[str]

@typing.type_check_only
class GPUSharingConfig(typing_extensions.TypedDict, total=False):
    gpuSharingStrategy: typing_extensions.Literal[
        "GPU_SHARING_STRATEGY_UNSPECIFIED", "TIME_SHARING"
    ]
    maxSharedClientsPerGpu: str

@typing.type_check_only
class GcePersistentDiskCsiDriverConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class GcfsConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class GcpFilestoreCsiDriverConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class GetJSONWebKeysResponse(typing_extensions.TypedDict, total=False):
    cacheHeader: HttpCacheControlResponseHeader
    keys: _list[Jwk]

@typing.type_check_only
class GetOpenIDConfigResponse(typing_extensions.TypedDict, total=False):
    cacheHeader: HttpCacheControlResponseHeader
    claims_supported: _list[str]
    grant_types: _list[str]
    id_token_signing_alg_values_supported: _list[str]
    issuer: str
    jwks_uri: str
    response_types_supported: _list[str]
    subject_types_supported: _list[str]

@typing.type_check_only
class GkeBackupAgentConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class HorizontalPodAutoscaling(typing_extensions.TypedDict, total=False):
    disabled: bool

@typing.type_check_only
class HttpCacheControlResponseHeader(typing_extensions.TypedDict, total=False):
    age: str
    directive: str
    expires: str

@typing.type_check_only
class HttpLoadBalancing(typing_extensions.TypedDict, total=False):
    disabled: bool

@typing.type_check_only
class ILBSubsettingConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class IPAllocationPolicy(typing_extensions.TypedDict, total=False):
    allowRouteOverlap: bool
    clusterIpv4Cidr: str
    clusterIpv4CidrBlock: str
    clusterSecondaryRangeName: str
    createSubnetwork: bool
    ipv6AccessType: typing_extensions.Literal[
        "IPV6_ACCESS_TYPE_UNSPECIFIED", "INTERNAL", "EXTERNAL"
    ]
    nodeIpv4Cidr: str
    nodeIpv4CidrBlock: str
    servicesIpv4Cidr: str
    servicesIpv4CidrBlock: str
    servicesIpv6CidrBlock: str
    servicesSecondaryRangeName: str
    stackType: typing_extensions.Literal["STACK_TYPE_UNSPECIFIED", "IPV4", "IPV4_IPV6"]
    subnetIpv6CidrBlock: str
    subnetworkName: str
    tpuIpv4CidrBlock: str
    useIpAliases: bool
    useRoutes: bool

@typing.type_check_only
class IdentityServiceConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class IntraNodeVisibilityConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class IstioConfig(typing_extensions.TypedDict, total=False):
    auth: typing_extensions.Literal["AUTH_NONE", "AUTH_MUTUAL_TLS"]
    disabled: bool

@typing.type_check_only
class Jwk(typing_extensions.TypedDict, total=False):
    alg: str
    crv: str
    e: str
    kid: str
    kty: str
    n: str
    use: str
    x: str
    y: str

@typing.type_check_only
class KalmConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class KubernetesDashboard(typing_extensions.TypedDict, total=False):
    disabled: bool

@typing.type_check_only
class LegacyAbac(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class LinuxNodeConfig(typing_extensions.TypedDict, total=False):
    cgroupMode: typing_extensions.Literal[
        "CGROUP_MODE_UNSPECIFIED", "CGROUP_MODE_V1", "CGROUP_MODE_V2"
    ]
    sysctls: dict[str, typing.Any]

@typing.type_check_only
class ListClustersResponse(typing_extensions.TypedDict, total=False):
    clusters: _list[Cluster]
    missingZones: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListNodePoolsResponse(typing_extensions.TypedDict, total=False):
    nodePools: _list[NodePool]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    missingZones: _list[str]
    operations: _list[Operation]

@typing.type_check_only
class ListUsableSubnetworksResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    subnetworks: _list[UsableSubnetwork]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    name: str
    recommended: bool
    type: typing_extensions.Literal["LOCATION_TYPE_UNSPECIFIED", "ZONE", "REGION"]

@typing.type_check_only
class LoggingComponentConfig(typing_extensions.TypedDict, total=False):
    enableComponents: _list[str]

@typing.type_check_only
class LoggingConfig(typing_extensions.TypedDict, total=False):
    componentConfig: LoggingComponentConfig

@typing.type_check_only
class LoggingVariantConfig(typing_extensions.TypedDict, total=False):
    variant: typing_extensions.Literal[
        "VARIANT_UNSPECIFIED", "DEFAULT", "MAX_THROUGHPUT"
    ]

@typing.type_check_only
class MaintenanceExclusionOptions(typing_extensions.TypedDict, total=False):
    scope: typing_extensions.Literal[
        "NO_UPGRADES", "NO_MINOR_UPGRADES", "NO_MINOR_OR_NODE_UPGRADES"
    ]

@typing.type_check_only
class MaintenancePolicy(typing_extensions.TypedDict, total=False):
    resourceVersion: str
    window: MaintenanceWindow

@typing.type_check_only
class MaintenanceWindow(typing_extensions.TypedDict, total=False):
    dailyMaintenanceWindow: DailyMaintenanceWindow
    maintenanceExclusions: dict[str, typing.Any]
    recurringWindow: RecurringTimeWindow

@typing.type_check_only
class ManagedPrometheusConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class Master(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class MasterAuth(typing_extensions.TypedDict, total=False):
    clientCertificate: str
    clientCertificateConfig: ClientCertificateConfig
    clientKey: str
    clusterCaCertificate: str
    password: str
    username: str

@typing.type_check_only
class MasterAuthorizedNetworksConfig(typing_extensions.TypedDict, total=False):
    cidrBlocks: _list[CidrBlock]
    enabled: bool

@typing.type_check_only
class MaxPodsConstraint(typing_extensions.TypedDict, total=False):
    maxPodsPerNode: str

@typing.type_check_only
class MeshCertificates(typing_extensions.TypedDict, total=False):
    enableCertificates: bool

@typing.type_check_only
class Metric(typing_extensions.TypedDict, total=False):
    doubleValue: float
    intValue: str
    name: str
    stringValue: str

@typing.type_check_only
class MonitoringComponentConfig(typing_extensions.TypedDict, total=False):
    enableComponents: _list[str]

@typing.type_check_only
class MonitoringConfig(typing_extensions.TypedDict, total=False):
    componentConfig: MonitoringComponentConfig
    managedPrometheusConfig: ManagedPrometheusConfig

@typing.type_check_only
class NetworkConfig(typing_extensions.TypedDict, total=False):
    datapathProvider: typing_extensions.Literal[
        "DATAPATH_PROVIDER_UNSPECIFIED", "LEGACY_DATAPATH", "ADVANCED_DATAPATH"
    ]
    defaultSnatStatus: DefaultSnatStatus
    dnsConfig: DNSConfig
    enableIntraNodeVisibility: bool
    enableL4ilbSubsetting: bool
    network: str
    privateIpv6GoogleAccess: typing_extensions.Literal[
        "PRIVATE_IPV6_GOOGLE_ACCESS_UNSPECIFIED",
        "PRIVATE_IPV6_GOOGLE_ACCESS_DISABLED",
        "PRIVATE_IPV6_GOOGLE_ACCESS_TO_GOOGLE",
        "PRIVATE_IPV6_GOOGLE_ACCESS_BIDIRECTIONAL",
    ]
    serviceExternalIpsConfig: ServiceExternalIPsConfig
    subnetwork: str

@typing.type_check_only
class NetworkPerformanceConfig(typing_extensions.TypedDict, total=False):
    externalIpEgressBandwidthTier: typing_extensions.Literal[
        "TIER_UNSPECIFIED", "TIER_1"
    ]
    totalEgressBandwidthTier: typing_extensions.Literal["TIER_UNSPECIFIED", "TIER_1"]

@typing.type_check_only
class NetworkPolicy(typing_extensions.TypedDict, total=False):
    enabled: bool
    provider: typing_extensions.Literal["PROVIDER_UNSPECIFIED", "CALICO"]

@typing.type_check_only
class NetworkPolicyConfig(typing_extensions.TypedDict, total=False):
    disabled: bool

@typing.type_check_only
class NetworkTags(typing_extensions.TypedDict, total=False):
    tags: _list[str]

@typing.type_check_only
class NodeConfig(typing_extensions.TypedDict, total=False):
    accelerators: _list[AcceleratorConfig]
    advancedMachineFeatures: AdvancedMachineFeatures
    bootDiskKmsKey: str
    confidentialNodes: ConfidentialNodes
    diskSizeGb: int
    diskType: str
    ephemeralStorageConfig: EphemeralStorageConfig
    gcfsConfig: GcfsConfig
    gvnic: VirtualNIC
    imageType: str
    kubeletConfig: NodeKubeletConfig
    labels: dict[str, typing.Any]
    linuxNodeConfig: LinuxNodeConfig
    localSsdCount: int
    loggingConfig: NodePoolLoggingConfig
    machineType: str
    metadata: dict[str, typing.Any]
    minCpuPlatform: str
    nodeGroup: str
    oauthScopes: _list[str]
    preemptible: bool
    reservationAffinity: ReservationAffinity
    sandboxConfig: SandboxConfig
    serviceAccount: str
    shieldedInstanceConfig: ShieldedInstanceConfig
    spot: bool
    tags: _list[str]
    taints: _list[NodeTaint]
    workloadMetadataConfig: WorkloadMetadataConfig

@typing.type_check_only
class NodeConfigDefaults(typing_extensions.TypedDict, total=False):
    gcfsConfig: GcfsConfig
    loggingConfig: NodePoolLoggingConfig

@typing.type_check_only
class NodeKubeletConfig(typing_extensions.TypedDict, total=False):
    cpuCfsQuota: bool
    cpuCfsQuotaPeriod: str
    cpuManagerPolicy: str
    podPidsLimit: str

@typing.type_check_only
class NodeLabels(typing_extensions.TypedDict, total=False):
    labels: dict[str, typing.Any]

@typing.type_check_only
class NodeManagement(typing_extensions.TypedDict, total=False):
    autoRepair: bool
    autoUpgrade: bool
    upgradeOptions: AutoUpgradeOptions

@typing.type_check_only
class NodeNetworkConfig(typing_extensions.TypedDict, total=False):
    createPodRange: bool
    networkPerformanceConfig: NetworkPerformanceConfig
    podIpv4CidrBlock: str
    podRange: str

@typing.type_check_only
class NodePool(typing_extensions.TypedDict, total=False):
    autoscaling: NodePoolAutoscaling
    conditions: _list[StatusCondition]
    config: NodeConfig
    initialNodeCount: int
    instanceGroupUrls: _list[str]
    locations: _list[str]
    management: NodeManagement
    maxPodsConstraint: MaxPodsConstraint
    name: str
    networkConfig: NodeNetworkConfig
    placementPolicy: PlacementPolicy
    podIpv4CidrSize: int
    selfLink: str
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "PROVISIONING",
        "RUNNING",
        "RUNNING_WITH_ERROR",
        "RECONCILING",
        "STOPPING",
        "ERROR",
    ]
    statusMessage: str
    updateInfo: UpdateInfo
    upgradeSettings: UpgradeSettings
    version: str

@typing.type_check_only
class NodePoolAutoConfig(typing_extensions.TypedDict, total=False):
    networkTags: NetworkTags

@typing.type_check_only
class NodePoolAutoscaling(typing_extensions.TypedDict, total=False):
    autoprovisioned: bool
    enabled: bool
    locationPolicy: typing_extensions.Literal[
        "LOCATION_POLICY_UNSPECIFIED", "BALANCED", "ANY"
    ]
    maxNodeCount: int
    minNodeCount: int
    totalMaxNodeCount: int
    totalMinNodeCount: int

@typing.type_check_only
class NodePoolDefaults(typing_extensions.TypedDict, total=False):
    nodeConfigDefaults: NodeConfigDefaults

@typing.type_check_only
class NodePoolLoggingConfig(typing_extensions.TypedDict, total=False):
    variantConfig: LoggingVariantConfig

@typing.type_check_only
class NodeTaint(typing_extensions.TypedDict, total=False):
    effect: typing_extensions.Literal[
        "EFFECT_UNSPECIFIED", "NO_SCHEDULE", "PREFER_NO_SCHEDULE", "NO_EXECUTE"
    ]
    key: str
    value: str

@typing.type_check_only
class NodeTaints(typing_extensions.TypedDict, total=False):
    taints: _list[NodeTaint]

@typing.type_check_only
class NotificationConfig(typing_extensions.TypedDict, total=False):
    pubsub: PubSub

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    clusterConditions: _list[StatusCondition]
    detail: str
    endTime: str
    error: Status
    location: str
    name: str
    nodepoolConditions: _list[StatusCondition]
    operationType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "CREATE_CLUSTER",
        "DELETE_CLUSTER",
        "UPGRADE_MASTER",
        "UPGRADE_NODES",
        "REPAIR_CLUSTER",
        "UPDATE_CLUSTER",
        "CREATE_NODE_POOL",
        "DELETE_NODE_POOL",
        "SET_NODE_POOL_MANAGEMENT",
        "AUTO_REPAIR_NODES",
        "AUTO_UPGRADE_NODES",
        "SET_LABELS",
        "SET_MASTER_AUTH",
        "SET_NODE_POOL_SIZE",
        "SET_NETWORK_POLICY",
        "SET_MAINTENANCE_POLICY",
    ]
    progress: OperationProgress
    selfLink: str
    startTime: str
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED", "PENDING", "RUNNING", "DONE", "ABORTING"
    ]
    statusMessage: str
    targetLink: str
    zone: str

@typing.type_check_only
class OperationProgress(typing_extensions.TypedDict, total=False):
    metrics: _list[Metric]
    name: str
    stages: _list[OperationProgress]
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED", "PENDING", "RUNNING", "DONE", "ABORTING"
    ]

@typing.type_check_only
class PlacementPolicy(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "COMPACT"]

@typing.type_check_only
class PodSecurityPolicyConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class PrivateClusterConfig(typing_extensions.TypedDict, total=False):
    enablePrivateEndpoint: bool
    enablePrivateNodes: bool
    masterGlobalAccessConfig: PrivateClusterMasterGlobalAccessConfig
    masterIpv4CidrBlock: str
    peeringName: str
    privateEndpoint: str
    publicEndpoint: str

@typing.type_check_only
class PrivateClusterMasterGlobalAccessConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class ProtectConfig(typing_extensions.TypedDict, total=False):
    workloadConfig: WorkloadConfig

@typing.type_check_only
class PubSub(typing_extensions.TypedDict, total=False):
    enabled: bool
    filter: Filter
    topic: str

@typing.type_check_only
class RecurringTimeWindow(typing_extensions.TypedDict, total=False):
    recurrence: str
    window: TimeWindow

@typing.type_check_only
class ReleaseChannel(typing_extensions.TypedDict, total=False):
    channel: typing_extensions.Literal["UNSPECIFIED", "RAPID", "REGULAR", "STABLE"]

@typing.type_check_only
class ReleaseChannelConfig(typing_extensions.TypedDict, total=False):
    availableVersions: _list[AvailableVersion]
    channel: typing_extensions.Literal["UNSPECIFIED", "RAPID", "REGULAR", "STABLE"]
    defaultVersion: str
    validVersions: _list[str]

@typing.type_check_only
class ReservationAffinity(typing_extensions.TypedDict, total=False):
    consumeReservationType: typing_extensions.Literal[
        "UNSPECIFIED", "NO_RESERVATION", "ANY_RESERVATION", "SPECIFIC_RESERVATION"
    ]
    key: str
    values: _list[str]

@typing.type_check_only
class ResourceLimit(typing_extensions.TypedDict, total=False):
    maximum: str
    minimum: str
    resourceType: str

@typing.type_check_only
class ResourceUsageExportConfig(typing_extensions.TypedDict, total=False):
    bigqueryDestination: BigQueryDestination
    consumptionMeteringConfig: ConsumptionMeteringConfig
    enableNetworkEgressMetering: bool

@typing.type_check_only
class RollbackNodePoolUpgradeRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    name: str
    nodePoolId: str
    projectId: str
    respectPdb: bool
    zone: str

@typing.type_check_only
class SandboxConfig(typing_extensions.TypedDict, total=False):
    sandboxType: str
    type: typing_extensions.Literal["UNSPECIFIED", "GVISOR"]

@typing.type_check_only
class SecurityBulletinEvent(typing_extensions.TypedDict, total=False):
    affectedSupportedMinors: _list[str]
    briefDescription: str
    bulletinId: str
    bulletinUri: str
    cveIds: _list[str]
    manualStepsRequired: bool
    patchedVersions: _list[str]
    resourceTypeAffected: str
    severity: str
    suggestedUpgradeTarget: str

@typing.type_check_only
class ServerConfig(typing_extensions.TypedDict, total=False):
    channels: _list[ReleaseChannelConfig]
    defaultClusterVersion: str
    defaultImageType: str
    validImageTypes: _list[str]
    validMasterVersions: _list[str]
    validNodeVersions: _list[str]
    windowsVersionMaps: dict[str, typing.Any]

@typing.type_check_only
class ServiceExternalIPsConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class SetAddonsConfigRequest(typing_extensions.TypedDict, total=False):
    addonsConfig: AddonsConfig
    clusterId: str
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class SetLabelsRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    labelFingerprint: str
    name: str
    projectId: str
    resourceLabels: dict[str, typing.Any]
    zone: str

@typing.type_check_only
class SetLegacyAbacRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    enabled: bool
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class SetLocationsRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    locations: _list[str]
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class SetLoggingServiceRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    loggingService: str
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class SetMaintenancePolicyRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    maintenancePolicy: MaintenancePolicy
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class SetMasterAuthRequest(typing_extensions.TypedDict, total=False):
    action: typing_extensions.Literal[
        "UNKNOWN", "SET_PASSWORD", "GENERATE_PASSWORD", "SET_USERNAME"
    ]
    clusterId: str
    name: str
    projectId: str
    update: MasterAuth
    zone: str

@typing.type_check_only
class SetMonitoringServiceRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    monitoringService: str
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class SetNetworkPolicyRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    name: str
    networkPolicy: NetworkPolicy
    projectId: str
    zone: str

@typing.type_check_only
class SetNodePoolAutoscalingRequest(typing_extensions.TypedDict, total=False):
    autoscaling: NodePoolAutoscaling
    clusterId: str
    name: str
    nodePoolId: str
    projectId: str
    zone: str

@typing.type_check_only
class SetNodePoolManagementRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    management: NodeManagement
    name: str
    nodePoolId: str
    projectId: str
    zone: str

@typing.type_check_only
class SetNodePoolSizeRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    name: str
    nodeCount: int
    nodePoolId: str
    projectId: str
    zone: str

@typing.type_check_only
class ShieldedInstanceConfig(typing_extensions.TypedDict, total=False):
    enableIntegrityMonitoring: bool
    enableSecureBoot: bool

@typing.type_check_only
class ShieldedNodes(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class StandardRolloutPolicy(typing_extensions.TypedDict, total=False):
    batchNodeCount: int
    batchPercentage: float
    batchSoakDuration: str

@typing.type_check_only
class StartIPRotationRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    name: str
    projectId: str
    rotateCredentials: bool
    zone: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StatusCondition(typing_extensions.TypedDict, total=False):
    canonicalCode: typing_extensions.Literal[
        "OK",
        "CANCELLED",
        "UNKNOWN",
        "INVALID_ARGUMENT",
        "DEADLINE_EXCEEDED",
        "NOT_FOUND",
        "ALREADY_EXISTS",
        "PERMISSION_DENIED",
        "UNAUTHENTICATED",
        "RESOURCE_EXHAUSTED",
        "FAILED_PRECONDITION",
        "ABORTED",
        "OUT_OF_RANGE",
        "UNIMPLEMENTED",
        "INTERNAL",
        "UNAVAILABLE",
        "DATA_LOSS",
    ]
    code: typing_extensions.Literal[
        "UNKNOWN",
        "GCE_STOCKOUT",
        "GKE_SERVICE_ACCOUNT_DELETED",
        "GCE_QUOTA_EXCEEDED",
        "SET_BY_OPERATOR",
        "CLOUD_KMS_KEY_ERROR",
        "CA_EXPIRING",
    ]
    message: str

@typing.type_check_only
class TimeWindow(typing_extensions.TypedDict, total=False):
    endTime: str
    maintenanceExclusionOptions: MaintenanceExclusionOptions
    startTime: str

@typing.type_check_only
class TpuConfig(typing_extensions.TypedDict, total=False):
    enabled: bool
    ipv4CidrBlock: str
    useServiceNetworking: bool

@typing.type_check_only
class UpdateClusterRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    name: str
    projectId: str
    update: ClusterUpdate
    zone: str

@typing.type_check_only
class UpdateInfo(typing_extensions.TypedDict, total=False):
    blueGreenInfo: BlueGreenInfo

@typing.type_check_only
class UpdateMasterRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    masterVersion: str
    name: str
    projectId: str
    zone: str

@typing.type_check_only
class UpdateNodePoolRequest(typing_extensions.TypedDict, total=False):
    clusterId: str
    confidentialNodes: ConfidentialNodes
    gcfsConfig: GcfsConfig
    gvnic: VirtualNIC
    imageType: str
    kubeletConfig: NodeKubeletConfig
    labels: NodeLabels
    linuxNodeConfig: LinuxNodeConfig
    locations: _list[str]
    loggingConfig: NodePoolLoggingConfig
    name: str
    nodeNetworkConfig: NodeNetworkConfig
    nodePoolId: str
    nodeVersion: str
    projectId: str
    tags: NetworkTags
    taints: NodeTaints
    upgradeSettings: UpgradeSettings
    workloadMetadataConfig: WorkloadMetadataConfig
    zone: str

@typing.type_check_only
class UpgradeAvailableEvent(typing_extensions.TypedDict, total=False):
    releaseChannel: ReleaseChannel
    resource: str
    resourceType: typing_extensions.Literal[
        "UPGRADE_RESOURCE_TYPE_UNSPECIFIED", "MASTER", "NODE_POOL"
    ]
    version: str
    windowsVersions: WindowsVersions

@typing.type_check_only
class UpgradeEvent(typing_extensions.TypedDict, total=False):
    currentVersion: str
    operation: str
    operationStartTime: str
    resource: str
    resourceType: typing_extensions.Literal[
        "UPGRADE_RESOURCE_TYPE_UNSPECIFIED", "MASTER", "NODE_POOL"
    ]
    targetVersion: str

@typing.type_check_only
class UpgradeSettings(typing_extensions.TypedDict, total=False):
    blueGreenSettings: BlueGreenSettings
    maxSurge: int
    maxUnavailable: int
    strategy: typing_extensions.Literal[
        "NODE_POOL_UPDATE_STRATEGY_UNSPECIFIED", "BLUE_GREEN", "SURGE"
    ]

@typing.type_check_only
class UsableSubnetwork(typing_extensions.TypedDict, total=False):
    ipCidrRange: str
    network: str
    secondaryIpRanges: _list[UsableSubnetworkSecondaryRange]
    statusMessage: str
    subnetwork: str

@typing.type_check_only
class UsableSubnetworkSecondaryRange(typing_extensions.TypedDict, total=False):
    ipCidrRange: str
    rangeName: str
    status: typing_extensions.Literal[
        "UNKNOWN",
        "UNUSED",
        "IN_USE_SERVICE",
        "IN_USE_SHAREABLE_POD",
        "IN_USE_MANAGED_POD",
    ]

@typing.type_check_only
class VerticalPodAutoscaling(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class VirtualNIC(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class WindowsVersion(typing_extensions.TypedDict, total=False):
    imageType: str
    osVersion: str
    supportEndDate: Date

@typing.type_check_only
class WindowsVersions(typing_extensions.TypedDict, total=False):
    windowsVersions: _list[WindowsVersion]

@typing.type_check_only
class WorkloadALTSConfig(typing_extensions.TypedDict, total=False):
    enableAlts: bool

@typing.type_check_only
class WorkloadCertificates(typing_extensions.TypedDict, total=False):
    enableCertificates: bool

@typing.type_check_only
class WorkloadConfig(typing_extensions.TypedDict, total=False):
    auditMode: typing_extensions.Literal[
        "MODE_UNSPECIFIED", "DISABLED", "BASIC", "BASELINE", "RESTRICTED"
    ]

@typing.type_check_only
class WorkloadIdentityConfig(typing_extensions.TypedDict, total=False):
    identityNamespace: str
    identityProvider: str
    workloadPool: str

@typing.type_check_only
class WorkloadMetadataConfig(typing_extensions.TypedDict, total=False):
    mode: typing_extensions.Literal["MODE_UNSPECIFIED", "GCE_METADATA", "GKE_METADATA"]
    nodeMetadata: typing_extensions.Literal[
        "UNSPECIFIED", "SECURE", "EXPOSE", "GKE_METADATA_SERVER"
    ]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudchannelResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ChannelPartnerLinksResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ChannelPartnerRepricingConfigsResource(
                googleapiclient.discovery.Resource
            ):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudChannelV1ChannelPartnerRepricingConfig = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1ChannelPartnerRepricingConfigHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudChannelV1ChannelPartnerRepricingConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponseHttpRequest,
                    previous_response: GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponse,
                ) -> GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1ChannelPartnerRepricingConfig = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1ChannelPartnerRepricingConfigHttpRequest: ...

            @typing.type_check_only
            class CustomersResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudChannelV1Customer = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1CustomerHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudChannelV1CustomerHttpRequest: ...
                def import_(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudChannelV1ImportCustomerRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1CustomerHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1ListCustomersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudChannelV1ListCustomersResponseHttpRequest,
                    previous_response: GoogleCloudChannelV1ListCustomersResponse,
                ) -> GoogleCloudChannelV1ListCustomersResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1Customer = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1CustomerHttpRequest: ...

            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudChannelV1ChannelPartnerLink = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ChannelPartnerLinkHttpRequest: ...
            def get(
                self,
                *,
                name: str,
                view: typing_extensions.Literal["UNSPECIFIED", "BASIC", "FULL"] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ChannelPartnerLinkHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal["UNSPECIFIED", "BASIC", "FULL"] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ListChannelPartnerLinksResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudChannelV1ListChannelPartnerLinksResponseHttpRequest,
                previous_response: GoogleCloudChannelV1ListChannelPartnerLinksResponse,
            ) -> GoogleCloudChannelV1ListChannelPartnerLinksResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudChannelV1UpdateChannelPartnerLinkRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ChannelPartnerLinkHttpRequest: ...
            def channelPartnerRepricingConfigs(
                self,
            ) -> ChannelPartnerRepricingConfigsResource: ...
            def customers(self) -> CustomersResource: ...

        @typing.type_check_only
        class CustomersResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class CustomerRepricingConfigsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudChannelV1CustomerRepricingConfig = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1CustomerRepricingConfigHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudChannelV1CustomerRepricingConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1ListCustomerRepricingConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudChannelV1ListCustomerRepricingConfigsResponseHttpRequest,
                    previous_response: GoogleCloudChannelV1ListCustomerRepricingConfigsResponse,
                ) -> GoogleCloudChannelV1ListCustomerRepricingConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1CustomerRepricingConfig = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1CustomerRepricingConfigHttpRequest: ...

            @typing.type_check_only
            class EntitlementsResource(googleapiclient.discovery.Resource):
                def activate(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1ActivateEntitlementRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def cancel(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1CancelEntitlementRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def changeOffer(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1ChangeOfferRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def changeParameters(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1ChangeParametersRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def changeRenewalSettings(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1ChangeRenewalSettingsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudChannelV1CreateEntitlementRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudChannelV1EntitlementHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudChannelV1ListEntitlementsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudChannelV1ListEntitlementsResponseHttpRequest,
                    previous_response: GoogleCloudChannelV1ListEntitlementsResponse,
                ) -> GoogleCloudChannelV1ListEntitlementsResponseHttpRequest | None: ...
                def lookupOffer(
                    self, *, entitlement: str, **kwargs: typing.Any
                ) -> GoogleCloudChannelV1OfferHttpRequest: ...
                def startPaidService(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1StartPaidServiceRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def suspend(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudChannelV1SuspendEntitlementRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...

            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudChannelV1Customer = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1CustomerHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudChannelV1CustomerHttpRequest: ...
            def import_(
                self,
                *,
                parent: str,
                body: GoogleCloudChannelV1ImportCustomerRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1CustomerHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ListCustomersResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudChannelV1ListCustomersResponseHttpRequest,
                previous_response: GoogleCloudChannelV1ListCustomersResponse,
            ) -> GoogleCloudChannelV1ListCustomersResponseHttpRequest | None: ...
            def listPurchasableOffers(
                self,
                *,
                customer: str,
                changeOfferPurchase_entitlement: str = ...,
                changeOfferPurchase_newSku: str = ...,
                createEntitlementPurchase_sku: str = ...,
                languageCode: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ListPurchasableOffersResponseHttpRequest: ...
            def listPurchasableOffers_next(
                self,
                previous_request: GoogleCloudChannelV1ListPurchasableOffersResponseHttpRequest,
                previous_response: GoogleCloudChannelV1ListPurchasableOffersResponse,
            ) -> GoogleCloudChannelV1ListPurchasableOffersResponseHttpRequest | None: ...
            def listPurchasableSkus(
                self,
                *,
                customer: str,
                changeOfferPurchase_changeType: typing_extensions.Literal[
                    "CHANGE_TYPE_UNSPECIFIED", "UPGRADE", "DOWNGRADE"
                ] = ...,
                changeOfferPurchase_entitlement: str = ...,
                createEntitlementPurchase_product: str = ...,
                languageCode: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ListPurchasableSkusResponseHttpRequest: ...
            def listPurchasableSkus_next(
                self,
                previous_request: GoogleCloudChannelV1ListPurchasableSkusResponseHttpRequest,
                previous_response: GoogleCloudChannelV1ListPurchasableSkusResponse,
            ) -> GoogleCloudChannelV1ListPurchasableSkusResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudChannelV1Customer = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1CustomerHttpRequest: ...
            def provisionCloudIdentity(
                self,
                *,
                customer: str,
                body: GoogleCloudChannelV1ProvisionCloudIdentityRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...
            def transferEntitlements(
                self,
                *,
                parent: str,
                body: GoogleCloudChannelV1TransferEntitlementsRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...
            def transferEntitlementsToGoogle(
                self,
                *,
                parent: str,
                body: GoogleCloudChannelV1TransferEntitlementsToGoogleRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...
            def customerRepricingConfigs(self) -> CustomerRepricingConfigsResource: ...
            def entitlements(self) -> EntitlementsResource: ...

        @typing.type_check_only
        class OffersResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                languageCode: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ListOffersResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudChannelV1ListOffersResponseHttpRequest,
                previous_response: GoogleCloudChannelV1ListOffersResponse,
            ) -> GoogleCloudChannelV1ListOffersResponseHttpRequest | None: ...

        def checkCloudIdentityAccountsExist(
            self,
            *,
            parent: str,
            body: GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudChannelV1CheckCloudIdentityAccountsExistResponseHttpRequest: ...
        def listSubscribers(
            self,
            *,
            account: str,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudChannelV1ListSubscribersResponseHttpRequest: ...
        def listSubscribers_next(
            self,
            previous_request: GoogleCloudChannelV1ListSubscribersResponseHttpRequest,
            previous_response: GoogleCloudChannelV1ListSubscribersResponse,
        ) -> GoogleCloudChannelV1ListSubscribersResponseHttpRequest | None: ...
        def listTransferableOffers(
            self,
            *,
            parent: str,
            body: GoogleCloudChannelV1ListTransferableOffersRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudChannelV1ListTransferableOffersResponseHttpRequest: ...
        def listTransferableOffers_next(
            self,
            previous_request: GoogleCloudChannelV1ListTransferableOffersResponseHttpRequest,
            previous_response: GoogleCloudChannelV1ListTransferableOffersResponse,
        ) -> GoogleCloudChannelV1ListTransferableOffersResponseHttpRequest | None: ...
        def listTransferableSkus(
            self,
            *,
            parent: str,
            body: GoogleCloudChannelV1ListTransferableSkusRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudChannelV1ListTransferableSkusResponseHttpRequest: ...
        def listTransferableSkus_next(
            self,
            previous_request: GoogleCloudChannelV1ListTransferableSkusResponseHttpRequest,
            previous_response: GoogleCloudChannelV1ListTransferableSkusResponse,
        ) -> GoogleCloudChannelV1ListTransferableSkusResponseHttpRequest | None: ...
        def register(
            self,
            *,
            account: str,
            body: GoogleCloudChannelV1RegisterSubscriberRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudChannelV1RegisterSubscriberResponseHttpRequest: ...
        def unregister(
            self,
            *,
            account: str,
            body: GoogleCloudChannelV1UnregisterSubscriberRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudChannelV1UnregisterSubscriberResponseHttpRequest: ...
        def channelPartnerLinks(self) -> ChannelPartnerLinksResource: ...
        def customers(self) -> CustomersResource: ...
        def offers(self) -> OffersResource: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def cancel(
            self,
            *,
            name: str,
            body: GoogleLongrunningCancelOperationRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleProtobufEmptyHttpRequest: ...
        def delete(
            self, *, name: str, **kwargs: typing.Any
        ) -> GoogleProtobufEmptyHttpRequest: ...
        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> GoogleLongrunningOperationHttpRequest: ...
        def list(
            self,
            *,
            name: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
            previous_response: GoogleLongrunningListOperationsResponse,
        ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class ProductsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SkusResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                account: str = ...,
                languageCode: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudChannelV1ListSkusResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudChannelV1ListSkusResponseHttpRequest,
                previous_response: GoogleCloudChannelV1ListSkusResponse,
            ) -> GoogleCloudChannelV1ListSkusResponseHttpRequest | None: ...

        def list(
            self,
            *,
            account: str = ...,
            languageCode: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudChannelV1ListProductsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GoogleCloudChannelV1ListProductsResponseHttpRequest,
            previous_response: GoogleCloudChannelV1ListProductsResponse,
        ) -> GoogleCloudChannelV1ListProductsResponseHttpRequest | None: ...
        def skus(self) -> SkusResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...
    def operations(self) -> OperationsResource: ...
    def products(self) -> ProductsResource: ...

@typing.type_check_only
class GoogleCloudChannelV1ChannelPartnerLinkHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ChannelPartnerLink: ...

@typing.type_check_only
class GoogleCloudChannelV1ChannelPartnerRepricingConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ChannelPartnerRepricingConfig: ...

@typing.type_check_only
class GoogleCloudChannelV1CheckCloudIdentityAccountsExistResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1CheckCloudIdentityAccountsExistResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1CustomerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1Customer: ...

@typing.type_check_only
class GoogleCloudChannelV1CustomerRepricingConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1CustomerRepricingConfig: ...

@typing.type_check_only
class GoogleCloudChannelV1EntitlementHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1Entitlement: ...

@typing.type_check_only
class GoogleCloudChannelV1ListChannelPartnerLinksResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListChannelPartnerLinksResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListChannelPartnerRepricingConfigsResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListCustomerRepricingConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListCustomerRepricingConfigsResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListCustomersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListCustomersResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListEntitlementsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListEntitlementsResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListOffersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListOffersResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListProductsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListProductsResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListPurchasableOffersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListPurchasableOffersResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListPurchasableSkusResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListPurchasableSkusResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListSkusResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListSkusResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListSubscribersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListSubscribersResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListTransferableOffersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListTransferableOffersResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1ListTransferableSkusResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1ListTransferableSkusResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1OfferHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1Offer: ...

@typing.type_check_only
class GoogleCloudChannelV1RegisterSubscriberResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1RegisterSubscriberResponse: ...

@typing.type_check_only
class GoogleCloudChannelV1UnregisterSubscriberResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudChannelV1UnregisterSubscriberResponse: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleMapsPlayablelocationsV3Impression(typing_extensions.TypedDict, total=False):
    gameObjectType: int
    impressionType: typing_extensions.Literal[
        "IMPRESSION_TYPE_UNSPECIFIED", "PRESENTED", "INTERACTED"
    ]
    locationName: str

@typing.type_check_only
class GoogleMapsPlayablelocationsV3LogImpressionsRequest(
    typing_extensions.TypedDict, total=False
):
    clientInfo: GoogleMapsUnityClientInfo
    impressions: _list[GoogleMapsPlayablelocationsV3Impression]
    requestId: str

@typing.type_check_only
class GoogleMapsPlayablelocationsV3LogImpressionsResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleMapsPlayablelocationsV3LogPlayerReportsRequest(
    typing_extensions.TypedDict, total=False
):
    clientInfo: GoogleMapsUnityClientInfo
    playerReports: _list[GoogleMapsPlayablelocationsV3PlayerReport]
    requestId: str

@typing.type_check_only
class GoogleMapsPlayablelocationsV3LogPlayerReportsResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleMapsPlayablelocationsV3PlayerReport(
    typing_extensions.TypedDict, total=False
):
    languageCode: str
    locationName: str
    reasonDetails: str
    reasons: _list[str]

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SampleAreaFilter(
    typing_extensions.TypedDict, total=False
):
    s2CellId: str

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SampleCriterion(
    typing_extensions.TypedDict, total=False
):
    fieldsToReturn: str
    filter: GoogleMapsPlayablelocationsV3SampleFilter
    gameObjectType: int

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SampleFilter(
    typing_extensions.TypedDict, total=False
):
    includedTypes: _list[str]
    maxLocationCount: int
    spacing: GoogleMapsPlayablelocationsV3SampleSpacingOptions

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SamplePlayableLocation(
    typing_extensions.TypedDict, total=False
):
    centerPoint: GoogleTypeLatLng
    name: str
    placeId: str
    plusCode: str
    snappedPoint: GoogleTypeLatLng
    types: _list[str]

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SamplePlayableLocationList(
    typing_extensions.TypedDict, total=False
):
    locations: _list[GoogleMapsPlayablelocationsV3SamplePlayableLocation]

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SamplePlayableLocationsRequest(
    typing_extensions.TypedDict, total=False
):
    areaFilter: GoogleMapsPlayablelocationsV3SampleAreaFilter
    criteria: _list[GoogleMapsPlayablelocationsV3SampleCriterion]

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SamplePlayableLocationsResponse(
    typing_extensions.TypedDict, total=False
):
    locationsPerGameObjectType: dict[str, typing.Any]
    ttl: str

@typing.type_check_only
class GoogleMapsPlayablelocationsV3SampleSpacingOptions(
    typing_extensions.TypedDict, total=False
):
    minSpacingMeters: float
    pointType: typing_extensions.Literal[
        "POINT_TYPE_UNSPECIFIED", "CENTER_POINT", "SNAPPED_POINT"
    ]

@typing.type_check_only
class GoogleMapsUnityClientInfo(typing_extensions.TypedDict, total=False):
    apiClient: str
    applicationId: str
    applicationVersion: str
    deviceModel: str
    languageCode: str
    operatingSystem: str
    operatingSystemBuild: str
    platform: typing_extensions.Literal[
        "PLATFORM_UNSPECIFIED",
        "EDITOR",
        "MAC_OS",
        "WINDOWS",
        "LINUX",
        "ANDROID",
        "IOS",
        "WEB_GL",
    ]

@typing.type_check_only
class GoogleTypeLatLng(typing_extensions.TypedDict, total=False):
    latitude: float
    longitude: float
